import java.util.Locale;
import java.util.logging.Level;

import org.eclipse.birt.core.exception.BirtException;
import org.eclipse.birt.core.framework.Platform;
import org.eclipse.birt.report.engine.api.EngineConfig;
import org.eclipse.birt.report.engine.api.EngineException;
import org.eclipse.birt.report.engine.api.IRenderOption;
import org.eclipse.birt.report.engine.api.IRenderTask;
import org.eclipse.birt.report.engine.api.IReportDocument;
import org.eclipse.birt.report.engine.api.IReportEngine;
import org.eclipse.birt.report.engine.api.IReportEngineFactory;
import org.eclipse.birt.report.engine.api.IReportRunnable;
import org.eclipse.birt.report.engine.api.IRunTask;
import org.eclipse.birt.report.engine.api.RenderOption;

import com.arctorus.export.birt26x.xlsx.EmitterConfig;

public class Demo {

    private static final String REPORT = "ProductCatalog";
    private static final String BIRT_RUNTIME_HOME = "./ReportEngine";
    private static final String LOG_DIR = "./logs";

    public static void main(String[] args) throws BirtException {
        IReportEngine engine = null;
        EngineConfig config = null;
        try {
            config = new EngineConfig();
            config.setBIRTHome(BIRT_RUNTIME_HOME);
            config.setLogConfig(LOG_DIR, Level.WARNING);
            Platform.startup(config);
            IReportEngineFactory factory = (IReportEngineFactory) Platform
                .createFactoryObject(IReportEngineFactory.EXTENSION_REPORT_ENGINE_FACTORY);
            engine = factory.createReportEngine(config);
            IReportRunnable design = null;
            design = engine.openReportDesign("reports/" + REPORT + ".rptdesign");
            IRunTask task = engine.createRunTask(design);
            task.run("reports/" + REPORT + ".rptdocument");
            task.close();
            IReportDocument iReportDocument = engine.openReportDocument("reports/" + REPORT + ".rptdocument");

            System.out.println("Started...");
            long startTime = System.currentTimeMillis();

            // Microsoft Word DOCX
            // export(engine, "docx", iReportDocument);

            // Microsoft PowerPoint PPTX
            // export(engine, "pptx", iReportDocument);

            // Microsoft Excel XLSX
            export(engine, "xlsx", iReportDocument);

            // Microsoft Excel XLS
            // export(engine, "xls", iReportDocument);

            // OpenOffice Writer ODT
            // export(engine, "odt", iReportDocument);

            // OpenOffice Impress ODP
            // export(engine, "odp", iReportDocument);

            // OpenOffice Calc ODS
            // export(engine, "ods", iReportDocument);

            System.out.println("   " + (System.currentTimeMillis() - startTime) + "ms");

            iReportDocument.close();
            engine.destroy();
        } catch (Exception ex) {
            ex.printStackTrace();
        } finally {
            Platform.shutdown();
        }
    }

    private static void export(IReportEngine engine, String type, IReportDocument iReportDocument) throws EngineException {

        IRenderOption options = new RenderOption();

        // Export report to a single sheet.
        // Option works with XLSX,XLS,ODS formats only.
        //
        // options.setOption(EmitterConfig.KEY_SINGLE_SHEET, true);

        // Set KEY_SHEET_NAME_PATTERN option to use special pattern for all sheets in a workbook.
        // Option works with XLSX,XLS,ODS formats only.
        //
        options.setOption(EmitterConfig.KEY_SHEET_NAME_TYPE, EmitterConfig.KEY_SHEET_NAME_PATTERN);
        options.setOption(EmitterConfig.KEY_SHEET_NAME_PATTERN, "ProductPage %d");

        // If a report contains constant number of page you can set name for every page in a workbook.
        // Set KEY_SHEET_NAME_COLLECTION option using sheet names divided by ":" or "+".
        // Option works with XLSX,XLS,ODS formats only.
        //
        // options.setOption(EmitterConfig.KEY_SHEET_NAME_TYPE, EmitterConfig.KEY_SHEET_NAME_COLLECTION);
        // options.setOption(EmitterConfig.KEY_SHEET_NAME_COLLECTION, "Product Catalog:More Products:One More Page:Fourth Page");

        // In case of KEY_SHEET_NAME_TABLES option emitter will use name of tables for sheet names.
        // If tables don't have defined names then KEY_SHEET_NAME_PATTERN will be used instead.
        // Option works with XLSX,XLS,ODS formats only.
        //
        // options.setOption(EmitterConfig.KEY_SHEET_NAME_TYPE, EmitterConfig.KEY_SHEET_NAME_TABLES);
        // options.setOption(EmitterConfig.KEY_SHEET_NAME_PATTERN, "ProductPage %d");

        // Protect workbook with password. Option works with XLSX,XLS formats only.
        //
        // options.setOption(EmitterConfig.KEY_PROTECT_WORKBOOK_PASSWORD, "12345678");

        // Protect sheet's content with password. Option works with XLSX,XLS formats only.
        //
        // options.setOption(EmitterConfig.KEY_PROTECT_SHEETS_PASSWORD, "12345678");

        // Encrypt whole workbook with password. Option works with XLSX,XLS formats only.
        //
        //options.setOption(EmitterConfig.KEY_ENCRYPT_WORKBOOK_PASSWORD, "12345678");

        // List of pages to export.
        //
        // options.setOption(EmitterConfig.KEY_PAGES_RANGE, "1-3");

        options.setOutputFormat(type);
        options.setEmitterID("com.arctorus.export.birt26x." + type);

        options.setOutputFileName("output/" + REPORT + "." + type);
        IRenderTask renderTask = engine.createRenderTask(iReportDocument);

        // Set locale before export if necessary
        //
        // renderTask.setLocale(Locale.US);

        renderTask.setRenderOption(options);
        renderTask.render();
        renderTask.close();
    }
}
